@@ -110,7 +110,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *   Other bugs? Catch them in a jar and send them to rfsber -(at)- xs4all.nl
  *
  ****
- * $Id: robodoc.c,v 1.113 2008/07/29 07:50:56 gumpu Exp $
+ * $Id: robodoc.c,v 1.115 2010/05/02 20:16:14 gumpu Exp $
  */
 
 #include <assert.h>
@@ -220,8 +220,8 @@ char                RB_VER[] =
 char                use[] =
 /*           1         2         3         4         5         6         7         8
     12345678901234567890123456789012345678901234567890123456789012345678901234567890 */
-    "ROBODoc Version " VERSION "    autodocs formatter ($Revision: 1.113 $)\n"
-    "(c) 1994-2008 Frans Slothouber, Petteri Kettunen, \n"
+    "ROBODoc Version " VERSION "    autodocs formatter ($Revision: 1.115 $)\n"
+    "(c) 1994-2010 Frans Slothouber, Petteri Kettunen, \n"
     "              Gergely Budai and Jacco van Weert\n"
     "ROBODoc comes with ABSOLUTELY NO WARRANTY.\n"
     "This is free software, and you are welcome to redistribute it\n"
@@ -299,6 +299,8 @@ char                use_options3[] =
     "                    (default value: 2, set to zero to disable)\n"
     "   --source_line_numbers\n"
     "                    Display original source line numbers for SOURCE items\n"
+    "   --use_source_comments ITEM\n"
+    "                    Add found source comment lines to documenatation of ITEM\n"
     "\n";
 char                use_authors[] =
     "Authors/Contributors:\n"
@@ -1302,6 +1304,13 @@ actions_t Find_Actions(
         }
     }
 
+    // Find item to use source comments
+    optstr = Find_Parameterized_Option( "--use_source_comments" );
+    if ( optstr )
+    {
+        use_source_comments = optstr;
+    }
+
     /* Find specific syntax colors enable options */
     optstr = Find_Parameterized_Option( "--syntaxcolors_enable" );
     if ( optstr )
